Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src Rename the autoloaded property list from <module>.prop to <m...



details:   https://anonhg.NetBSD.org/src/rev/d3713f34e053
branches:  trunk
changeset: 759089:d3713f34e053
user:      jnemeth <jnemeth%NetBSD.org@localhost>
date:      Sun Nov 28 00:26:38 2010 +0000

description:
Rename the autoloaded property list from <module>.prop to <module>.plist
as discussed on tech-kern.

diffstat:

 doc/CHANGES                |   3 ++-
 lib/libc/sys/modctl.2      |   8 ++++----
 share/man/man9/module.9    |   6 +++---
 sys/kern/kern_module_vfs.c |  14 +++++++-------
 4 files changed, 16 insertions(+), 15 deletions(-)

diffs (119 lines):

diff -r 3b8c083e4587 -r d3713f34e053 doc/CHANGES
--- a/doc/CHANGES       Sat Nov 27 23:08:45 2010 +0000
+++ b/doc/CHANGES       Sun Nov 28 00:26:38 2010 +0000
@@ -1,4 +1,4 @@
-# LIST OF CHANGES FROM LAST RELEASE:                   <$Revision: 1.1463 $>
+# LIST OF CHANGES FROM LAST RELEASE:                   <$Revision: 1.1464 $>
 #
 #
 # [Note: This file does not mention every change made to the NetBSD source tree.
@@ -791,3 +791,4 @@
        openssh: Import 5.6. [adam 20101121]
        dhcpcd(8): Import dhcpcd-5.2.9. [roy 20101127]
        postfix(1): Import version 2.7.2 [tron 20101127]
+       module: Rename <module>.prop to <module>.plist.  [jnemeth 20101127]
diff -r 3b8c083e4587 -r d3713f34e053 lib/libc/sys/modctl.2
--- a/lib/libc/sys/modctl.2     Sat Nov 27 23:08:45 2010 +0000
+++ b/lib/libc/sys/modctl.2     Sun Nov 28 00:26:38 2010 +0000
@@ -1,4 +1,4 @@
-.\"    $NetBSD: modctl.2,v 1.5 2010/08/18 01:55:32 pgoyette Exp $
+.\"    $NetBSD: modctl.2,v 1.6 2010/11/28 00:26:38 jnemeth Exp $
 .\"
 .\" Copyright (c) 2009 The NetBSD Foundation, Inc.
 .\" All rights reserved.
@@ -24,7 +24,7 @@
 .\" ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 .\" POSSIBILITY OF SUCH DAMAGE.
 .\"
-.Dd October 26, 2009
+.Dd November 27, 2010
 .Dt MODCTL 2
 .Os
 .Sh NAME
@@ -98,7 +98,7 @@
 Zero or more of the following flag values:
 .Bl -tag -compact -width "MODCTL_LOAD_FORCE"
 .It Dv MODCTL_NO_PROP
-Don't load \*[Lt]module\*[Gt].prop.
+Don't load \*[Lt]module\*[Gt].plist.
 .It Dv MODCTL_LOAD_FORCE
 Ignore kernel version mismatch.
 .El
@@ -221,7 +221,7 @@
 is not
 .Dv 0 .
 The kernel is unable to internalize the plist.
-Or, there is a problem with the module or \*[Lt]module\*[Gt].prop.
+Or, there is a problem with the module or \*[Lt]module\*[Gt].plist.
 .It Bq Er EMLINK
 The argument
 .Fa operation
diff -r 3b8c083e4587 -r d3713f34e053 share/man/man9/module.9
--- a/share/man/man9/module.9   Sat Nov 27 23:08:45 2010 +0000
+++ b/share/man/man9/module.9   Sun Nov 28 00:26:38 2010 +0000
@@ -1,4 +1,4 @@
-.\"    $NetBSD: module.9,v 1.21 2010/08/25 06:45:35 jnemeth Exp $
+.\"    $NetBSD: module.9,v 1.22 2010/11/28 00:26:38 jnemeth Exp $
 .\"
 .\" Copyright (c) 2010 The NetBSD Foundation, Inc.
 .\" All rights reserved.
@@ -27,7 +27,7 @@
 .\" ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 .\" POSSIBILITY OF SUCH DAMAGE.
 .\"
-.Dd August 25, 2010
+.Dd November 27, 2010
 .Dt MODULE 9
 .Os
 .Sh NAME
@@ -199,7 +199,7 @@
 .Dv MODCTL_NO_PROP
 flag is not set, the system searches for a file with the same name as the
 module file, but with the suffix
-.Dq Pa .prop .
+.Dq Pa .plist .
 If this file is found, the prop_dictionary it contains is loaded and
 merged with the prop_dictionary from the
 .Fa props
diff -r 3b8c083e4587 -r d3713f34e053 sys/kern/kern_module_vfs.c
--- a/sys/kern/kern_module_vfs.c        Sat Nov 27 23:08:45 2010 +0000
+++ b/sys/kern/kern_module_vfs.c        Sun Nov 28 00:26:38 2010 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: kern_module_vfs.c,v 1.9 2010/11/19 06:44:43 dholland Exp $     */
+/*     $NetBSD: kern_module_vfs.c,v 1.10 2010/11/28 00:26:38 jnemeth Exp $     */
 
 /*-
  * Copyright (c) 2008 The NetBSD Foundation, Inc.
@@ -34,7 +34,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: kern_module_vfs.c,v 1.9 2010/11/19 06:44:43 dholland Exp $");
+__KERNEL_RCSID(0, "$NetBSD: kern_module_vfs.c,v 1.10 2010/11/28 00:26:38 jnemeth Exp $");
 
 #define _MODULE_INTERNAL
 #include <sys/param.h>
@@ -100,7 +100,7 @@
        }
 
        /*
         * Load and process <module>.prop if it exists.
         */
        if (((flags & MODCTL_NO_PROP) == 0 && filedictp) || autoload) {
                error = module_load_plist_vfs(path, nochroot, &moduledict);
@@ -159,10 +159,10 @@
        proppath = PNBUF_GET();
        strcpy(proppath, modpath);
        pathlen = strlen(proppath);
-       if ((pathlen >= 5) && (strcmp(&proppath[pathlen - 5], ".kmod") == 0)) {
-               strcpy(&proppath[pathlen - 5], ".prop");
-       } else if (pathlen < MAXPATHLEN - 5) {
-                       strcat(proppath, ".prop");
+       if ((pathlen >= 6) && (strcmp(&proppath[pathlen - 5], ".kmod") == 0)) {
+               strcpy(&proppath[pathlen - 5], ".plist");
+       } else if (pathlen < MAXPATHLEN - 6) {
+                       strcat(proppath, ".plist");
        } else {
                error = ENOENT;
                goto out1;
@@ -100,7 +100,7 @@
 
        /*
-        * Load and process <module>.prop if it exists.
+        * Load and process <module>.plist if it exists.
         */
        if (((flags & MODCTL_NO_PROP) == 0 && filedictp) || autoload) {



Home | Main Index | Thread Index | Old Index